.. _api_authentication_module:

:mod:`bimmer_connected.api`
===========================

The :mod:`bimmer_connected.api` module contains helper functions to communicate with the BMW APIs.

:mod:`bimmer_connected.api.authentication`
------------------------------------------
 
.. automodule:: bimmer_connected.api.authentication
    :members:
    :undoc-members:


:mod:`bimmer_connected.api.client`
------------------------------------------
 
.. automodule:: bimmer_connected.api.client
    :members:
    :undoc-members:


:mod:`bimmer_connected.api.regions`
------------------------------------------
 
.. automodule:: bimmer_connected.api.regions
    :members:
    :undoc-members:


:mod:`bimmer_connected.api.utils`
------------------------------------------
 
.. automodule:: bimmer_connected.api.utils
    :members:
    :undoc-members:
